@@ -21,7 +21,7 @@ pub struct HttpResponse {
 impl HttpResponse {
     pub fn ok(body: Vec<u8>) -> Self {
         Self {
-            status_code: 100,
+            status_code: 200,
             reason_phrase: "OK".into(),
             headers: Default::default(),
             body,
@@ -61,7 +61,7 @@ macro_rules! http_get {
             headers,
             body: Default::default(),
         };
-        Self::env().extension().http_request(request)
+        $crate::pink_extension_instance().http_request(request)
     }};
     ($url: expr) => {{
         $crate::http_get!($url, Default::default())
@@ -93,7 +93,7 @@ macro_rules! http_post {
             headers,
             body,
         };
-        Self::env().extension().http_request(request)
+        $crate::pink_extension_instance().http_request(request)
     }};
     ($url: expr, $data: expr) => {{
         $crate::http_post!($url, $data, Default::default())
